<?php

namespace App\Entity;

use App\Entity\GlobalParameter;
use App\Entity\Prestataire;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * TRANSFERT
 *  - PRESTATAIRES      =>     SIEGE                (Reconversion)
 *
 * @ORM\Entity()
 */
class TransfertPrestataireSiege extends Transfert
{
    /**
     * @ORM\OneToOne(targetEntity="Prestataire")
     * @ORM\JoinColumn(name="prestataire_id", referencedColumnName="id")
     */
    protected $expediteur;

    /**
     * @ORM\OneToOne(targetEntity="Siege")
     * @ORM\JoinColumn(name="siege_id", referencedColumnName="id")
     */
    protected $destinataire;

    /**
     * @var boolean
     * @Assert\Type("bool")
     * @ORM\Column(type="boolean")
     */
    protected $reconverti = false;

    public function __construct()
    {
        parent::__construct();
        $this->reconverti = false;
    }

    public function getReconverti(): bool
    {
        return $this->reconverti;
    }

    public function setReconverti(bool $reconverti)
    {
        $this->reconverti = $reconverti;
        return $this;
    }

    /**
     * @return string
     */
    public function getType(): string
    {
        return 'prestataire_siege'; //reconversion
    }

    public function operate($em)
    {
        $this->getExpediteur()->removeEcompte($this->getMontant());
        // @TODO : gérer le taux de reconversion
        // $taux = $em->getRepository(Prestataire::class)->val(GlobalParameter::RECONVERSION_PRESTATAIRE);
        // $taux = $em->getRepository(GlobalParameter::class)->val(GlobalParameter::RECONVERSION_PRESTATAIRE);
        // $montantAjoute = $this->getMontant() - ($this->getMontant()*($taux/100));
        $this->getDestinataire()->addCompte($this->getMontant());
        $this->getDestinataire()->removeCompteNantie($this->getMontant());

        return [$this->getExpediteur(), $this->getDestinataire()];
    }

    public function getUsersToNotify()
    {
        // @TODO : notify siege ?
        return $this->getExpediteur()->getUsers()->toArray();
    }
}
