<?php

namespace App\Repository;

use App\Entity\Groupe;
use App\Entity\Groupeprestataire;
use App\Entity\Prestataire;
use App\Entity\Rubrique;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Symfony\Bridge\Doctrine\RegistryInterface;

/**
 * @method Prestataire|null find($id, $lockMode = null, $lockVersion = null)
 * @method Prestataire|null findOneBy(array $criteria, array $orderBy = null)
 * @method Prestataire[]    findAll()
 * @method Prestataire[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class PrestataireRepository extends ServiceEntityRepository
{
    public function __construct(RegistryInterface $registry)
    {
        parent::__construct($registry, Prestataire::class);
    }

    /**
    * @return Prestataire[] Returns an array of Prestataire objects
    */
    public function findByRubrique(Rubrique $rubrique)
    {
        $qb = $this->createQueryBuilder('p');
        return $qb
            ->where($qb->expr()->isMemberOf(':rubrique', 'p.rubriques'))
            ->andWhere('p.enabled = :enabled')
            ->setParameter('rubrique', $rubrique)
            ->setParameter('enabled', true)
            ->orderBy('p.raison', 'ASC')
            ->getQuery()
            ->getResult()
        ;
    }

    /**
    * @return Prestataire[] Returns an array of Prestataire objects
    */
    public function findByGroupeLocal(Groupe $groupe)
    {
        $qb = $this->createQueryBuilder('p');
        return $qb
            ->where('p.groupe = :groupe')
            ->andWhere('p.enabled = :enabled')
            ->setParameter('groupe', $groupe)
            ->setParameter('enabled', true)
            ->orderBy('p.raison', 'ASC')
            ->getQuery()
            ->getResult()
        ;
    }

    /**
    * @return Prestataire[] Returns an array of Prestataire objects
    */
    public function findByGroupeprestataire(Groupeprestataire $groupe)
    {
        $qb = $this->createQueryBuilder('p');
        return $qb
            ->where($qb->expr()->isMemberOf(':groupe', 'p.groupeprestataires'))
            ->andWhere('p.enabled = :enabled')
            ->setParameter('groupe', $groupe)
            ->setParameter('enabled', true)
            ->orderBy('p.raison', 'ASC')
            ->getQuery()
            ->getResult()
        ;
    }

    /**
    * @return Prestataire[] Returns an array of Prestataire objects
    */
    public function findbyExclude(Prestataire $presta)
    {
        $qb = $this->createQueryBuilder('p');
        return $qb
            ->where('p.id != :presta')
            ->andWhere('p.enabled = :enabled')
            ->setParameter('presta', $presta->getId())
            ->setParameter('enabled', true)
            ->orderBy('p.raison', 'ASC')
            ->getQuery()
            ->getResult()
        ;
    }
}
